
"""Allow packaging things up for Pypi."""

import os
import distutils.core

version = '1.21'


def unlinker(filename):
    """Delete a file. Do not error if there is a problem doing so."""
    try:
        os.unlink(filename)
    except (OSError, IOError):
        pass


# These two are symlinks to themselves; they confuse distutils, so we delete them for setup.py's benefit
unlinker('tests/57-symlinks/to-be-saved/a/b/1')
unlinker('tests/57-symlinks/to-be-saved/c/d/2')


distutils.core.setup(
    name='backshift',
    py_modules=[
        'backshift_file_mod',
        'backshift_os_mod',
        'base255',
        'bloom_filter_mod',
        'bufsock',
        'cacher_mod',
        'chunk_mod_bdb',
        'chunk_mod',
        'chunk_mod_traditional',
        'comma_mod',
        'compressed_file_mod',
        'compressed_string_mod',
        'constants_mod',
        'db_mod',
        'dirops_mod',
        'dohdbm',
        'escape_mod',
        'expire_mod',
        'file_count_mod',
        'hardlinks_mod',
        'helpers',
        'main',
        'metadata_mod',
        'modunits',
        'py_treap',
        'readline0',
        'repo_mod',
        'rolling_checksum_py_mod',
        'saveset_files_mod',
        'saveset_summary_mod',
        'stringio',
        'treap',
        'try_psyco',
        'xz_mod',
        ],
    version=version,
    description='Filesystem backup (deduplicating, compressed with xz or bzip2)',
    long_description='''
Backshift is a filesystem to filesystem backup program, analogous to rsync --link-dest.

Compared to rsync, backshift deduplicates much better, and compresses files - rsync does not.

Content-based, variable length chunks are deduplicated.

It runs unmodified on CPython 2.[567], CPython 3.x, Pypy, Pypy3 and Jython.

Backshift runs fastest on Pypy, but you can also use a Cython-enhanced innermost loop with CPython 2.x or 3.x.

Backshift is I/O bound.  CPU isn't much of an issue, except during the first backup of a given filesystem.
''',
    author='Daniel Richard Stromberg',
    author_email='strombrg@gmail.com',
    url='http://stromberg.dnsalias.org/~strombrg/backshift/',
    platforms='Cross platform',
    license='GPL, MIT, UCI, Apache (all opensource)',
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        ],
    )
